@@ -7,7 +7,7 @@ use 5.008_001;
 
 use Scalar::Util qw();
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub GC_FACTOR () { 10 }
 
@@ -64,6 +64,13 @@ sub get {
     $$value_ref;
 }
 
+sub clear {
+    my $self = shift;
+
+    $self->{_entries} = {};
+    $self->{_fifo} = [];    
+}
+
 sub _update_fifo {
     # precondition: $self->{_entries} should contain given key
     my ($self, $key, $value_ref) = @_;
@@ -126,6 +133,10 @@ Stores the given key-value pair.
 
 Removes data associated to the given key and returns the old value, if any.
 
+=head2 $cache->clear($key)
+
+Removes all entries from the cache.
+
 =head1 AUTHOR
 
 Kazuho Oku
